/*
 * This code implements the MD5 message-digest algorithm.
 * The algorithm is due to Ron Rivest.  This code was
 * written by Colin Plumb in 1993, no copyright is claimed.
 * This code is in the public domain; do with it what you wish.
 *
 * Equivalent code is available from RSA Data Security, Inc.
 * This code has been tested against that, and is equivalent,
 * except that you don't need to include two pages of legalese
 * with every copy.
 *
 * Ported by Electric Cloud, Inc. in 2015, but
 * this MD5 code is still in the public domain.
 */

#ifndef _MD5_H_
#define _MD5_H_

#include <vrpsx_stdint.h>
#include <stddef.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define MD5_BLOCK_LENGTH                64
#define MD5_DIGEST_LENGTH               16
#define MD5_DIGEST_STRING_LENGTH        (MD5_DIGEST_LENGTH * 2 + 1)

typedef struct MD5Context {
    vrpsx_uint32_t state[4];                 /* state */
    vrpsx_uint64_t count;                    /* number of bits, mod 2^64 */
    vrpsx_uint8_t buffer[MD5_BLOCK_LENGTH];  /* input buffer */
} MD5_CTX;

void MD5Init(MD5_CTX *);
void MD5Update(MD5_CTX *, const vrpsx_uint8_t *, size_t);
void MD5Pad(MD5_CTX *);
void MD5Final(vrpsx_uint8_t [MD5_DIGEST_LENGTH], MD5_CTX *);
void MD5Transform(vrpsx_uint32_t [4], const vrpsx_uint8_t [MD5_BLOCK_LENGTH]);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _MD5_H_ */
